package xyz.tbvns.ui;

import lombok.Getter;
import org.reflections.Reflections;

import java.lang.reflect.InvocationTargetException;
import java.util.*;

public class UIManager {
    private static List<UIElement> registeredUiElements = new ArrayList<>();
    private static List<MenuBarTab> registeredMenuBarTabs = new ArrayList<>();
    @Getter
    private static final HashMap<Class, Boolean> activeUI = new HashMap<>();

    public static void loadUi() {
        try {
            Reflections reflections = new Reflections("xyz.tbvns.ui.Elements");
            Set<Class<? extends UIElement>> elements = reflections.getSubTypesOf(UIElement.class);
            for (Class<? extends UIElement> element : elements) {
                registeredUiElements.add(element.getDeclaredConstructor().newInstance());
                activeUI.put(element.getClass(), false);
            }

            reflections = new Reflections("xyz.tbvns.ui.MenuBarTabs");
            Set<Class<? extends MenuBarTab>> tabs = reflections.getSubTypesOf(MenuBarTab.class);
            for (Class<? extends MenuBarTab> element : tabs) {
                registeredMenuBarTabs.add(element.getDeclaredConstructor().newInstance());
            }
            registeredMenuBarTabs.sort(Comparator.comparingInt(MenuBarTab::index));
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    public static void render() {
        for (UIElement element : registeredUiElements) {
            boolean isEnabled = activeUI.get(element.getClass());
            if (isEnabled) {
                element.render();
            }
        }
    }

    public static void renderMenuBarTabs() {
        for (MenuBarTab tab : registeredMenuBarTabs) {
            tab.render();
        }
    }
}
